summaryrefslogtreecommitdiff
path: root/indra/newview/llparticipantlist.cpp
diff options
context:
space:
mode:
authorAlexanderP ProductEngine <apaschenko@productengine.com>2012-11-09 12:45:36 +0200
committerAlexanderP ProductEngine <apaschenko@productengine.com>2012-11-09 12:45:36 +0200
commit486bdf32845e248ec4923224f1f4ea5d239ac0f3 (patch)
tree3d7634bea08a5aca5394ea2500f602cd325f3ac2 /indra/newview/llparticipantlist.cpp
parent3d70cca7029cc536725088c8ff5d58ad0222eb64 (diff)
CHUI-337 FIXED: To avoid confusion with a classes "...conversation..." and in accordance with the naming convention in the project, some classes and corresponding files should be renamed:
LLIMConversation -> LLFloaterIMSessionTab LLIMFloater -> LLFloaterIMSession LLNearbyChat -> LLFloaterIMNearbyChat LLIMFloaterContainer -> LLFloaterIMContainer LLNearbyChatBarListener -> LLFloaterIMNearbyChatListener LLNearbyChatHandler -> LLFloaterIMNearbyChatHandler
Diffstat (limited to 'indra/newview/llparticipantlist.cpp')
-rw-r--r--indra/newview/llparticipantlist.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llparticipantlist.cpp b/indra/newview/llparticipantlist.cpp
index 9a4d1166db..9f89b5f809 100644
--- a/indra/newview/llparticipantlist.cpp
+++ b/indra/newview/llparticipantlist.cpp
@@ -28,7 +28,7 @@
#include "llavatarnamecache.h"
#include "llimview.h"
-#include "llimfloatercontainer.h"
+#include "llfloaterimcontainer.h"
#include "llparticipantlist.h"
#include "llspeakers.h"
@@ -316,7 +316,7 @@ bool LLParticipantList::onSpeakerUpdateEvent(LLPointer<LLOldEvents::LLEvent> eve
if ( evt_data.has("id") )
{
LLUUID participant_id = evt_data["id"];
- LLIMFloaterContainer* im_box = LLIMFloaterContainer::findInstance();
+ LLFloaterIMContainer* im_box = LLFloaterIMContainer::findInstance();
if (im_box)
{
im_box->setTimeNow(mUUID,participant_id);
@@ -345,7 +345,7 @@ bool LLParticipantList::onModeratorUpdateEvent(LLPointer<LLOldEvents::LLEvent> e
mModeratorList.erase(id);
}
}
// *TODO : do we have to fire an event so that LLIMConversation::refreshConversation() gets called
}
}
return true;
@@ -345,7 +345,7 @@ bool LLParticipantList::onModeratorUpdateEvent(LLPointer<LLOldEvents::LLEvent> e
}
}
- // *TODO : do we have to fire an event so that LLIMConversation::refreshConversation() gets called
+ // *TODO : do we have to fire an event so that LLFloaterIMSessionTab::refreshConversation() gets called
}
}